@@ -181,6 +181,7 @@ static void on_stream_state_changed(void *_data, enum pw_stream_state old,
 
 		pw_loop_update_timer(pw_main_loop_get_loop(data->loop),
 				data->timer, &timeout, &interval, false);
+		break;
 	}
 	default:
 		break;
@@ -249,7 +250,6 @@ on_stream_param_changed(void *_data, uint32_t id, const struct spa_pod *param)
 		SPA_PARAM_BUFFERS_blocks,  SPA_POD_Int(1),
 		SPA_PARAM_BUFFERS_size,    SPA_POD_Int(data->stride * data->size.height),
 		SPA_PARAM_BUFFERS_stride,  SPA_POD_Int(data->stride),
-		SPA_PARAM_BUFFERS_align,   SPA_POD_Int(16),
 		SPA_PARAM_BUFFERS_dataType, SPA_POD_CHOICE_FLAGS_Int((1<<SPA_DATA_MemPtr)));
 
 	/* we are done */
@@ -317,8 +317,7 @@ static int reneg_buffers(struct data *data)
 		SPA_PARAM_BUFFERS_buffers, SPA_POD_CHOICE_RANGE_Int(8, 2, MAX_BUFFERS),
 		SPA_PARAM_BUFFERS_blocks,  SPA_POD_Int(1),
 		SPA_PARAM_BUFFERS_size,    SPA_POD_Int(data->stride * data->size.height),
-		SPA_PARAM_BUFFERS_stride,  SPA_POD_Int(data->stride),
-		SPA_PARAM_BUFFERS_align,   SPA_POD_Int(16));
+		SPA_PARAM_BUFFERS_stride,  SPA_POD_Int(data->stride));
 
 	pw_stream_update_params(data->stream, params, 1);
 
