@@ -32,12 +32,10 @@
 #include "../module.h"
 #include "registry.h"
 
-#define ERROR_RETURN(str) 		\
-	{ 				\
-		pw_log_error(str); 	\
-		res = -EINVAL; 		\
-		goto out; 		\
-	}
+#define NAME "remap-sink"
+
+PW_LOG_TOPIC_STATIC(mod_topic, "mod." NAME);
+#define PW_LOG_TOPIC_DEFAULT mod_topic
 
 struct module_remap_sink_data {
 	struct module *module;
@@ -62,27 +60,6 @@ static const struct pw_impl_module_events module_events = {
 	.destroy = module_destroy
 };
 
-static void serialize_dict(FILE *f, const struct spa_dict *dict)
-{
-	const struct spa_dict_item *it;
-	spa_dict_for_each(it, dict) {
-		size_t len = it->value ? strlen(it->value) : 0;
-		fprintf(f, " \"%s\" = ", it->key);
-		if (it->value == NULL) {
-			fprintf(f, "null");
-		} else if ( spa_json_is_null(it->value, len) ||
-		    spa_json_is_float(it->value, len) ||
-		    spa_json_is_object(it->value, len)) {
-			fprintf(f, "%s", it->value);
-		} else {
-			size_t size = (len+1) * 4;
-			char str[size];
-				spa_json_encode_string(str, size, it->value);
-			fprintf(f, "%s", str);
-		}
-	}
-}
-
 static int module_remap_sink_load(struct client *client, struct module *module)
 {
 	struct module_remap_sink_data *data = module->user_data;
@@ -90,16 +67,16 @@ static int module_remap_sink_load(struct client *client, struct module *module)
 	char *args;
 	size_t size;
 
-	pw_properties_setf(data->capture_props, PW_KEY_NODE_GROUP, "remap-sink-%u", module->idx);
-	pw_properties_setf(data->playback_props, PW_KEY_NODE_GROUP, "remap-sink-%u", module->idx);
+	pw_properties_setf(data->capture_props, PW_KEY_NODE_GROUP, "remap-sink-%u", module->index);
+	pw_properties_setf(data->playback_props, PW_KEY_NODE_GROUP, "remap-sink-%u", module->index);
 
 	f = open_memstream(&args, &size);
 	fprintf(f, "{");
-	serialize_dict(f, &module->props->dict);
+	pw_properties_serialize_dict(f, &module->props->dict, 0);
 	fprintf(f, " capture.props = {");
-	serialize_dict(f, &data->capture_props->dict);
+	pw_properties_serialize_dict(f, &data->capture_props->dict, 0);
 	fprintf(f, " } playback.props = {");
-	serialize_dict(f, &data->playback_props->dict);
+	pw_properties_serialize_dict(f, &data->playback_props->dict, 0);
 	fprintf(f, " } }");
 	fclose(f);
 
@@ -115,9 +92,6 @@ static int module_remap_sink_load(struct client *client, struct module *module)
 			&data->mod_listener,
 			&module_events, data);
 
-	pw_log_info("loaded module %p id:%u name:%s", module, module->idx, module->name);
-	module_emit_loaded(module, 0);
-
 	return 0;
 }
 
@@ -125,13 +99,15 @@ static int module_remap_sink_unload(struct client *client, struct module *module
 {
 	struct module_remap_sink_data *d = module->user_data;
 
-	pw_log_info("unload module %p id:%u name:%s", module, module->idx, module->name);
-
 	if (d->mod) {
 		spa_hook_remove(&d->mod_listener);
 		pw_impl_module_destroy(d->mod);
 		d->mod = NULL;
 	}
+
+	pw_properties_free(d->capture_props);
+	pw_properties_free(d->playback_props);
+
 	return 0;
 }
 
@@ -163,9 +139,9 @@ static void position_to_props(struct spa_audio_info_raw *info, struct pw_propert
 	uint32_t i;
 
 	pw_properties_setf(props, SPA_KEY_AUDIO_CHANNELS, "%u", info->channels);
-	p = s = alloca(info->channels * 6);
+	p = s = alloca(info->channels * 8);
 	for (i = 0; i < info->channels; i++)
-		p += snprintf(p, 6, "%s%s", i == 0 ? "" : ",",
+		p += spa_scnprintf(p, 8, "%s%s", i == 0 ? "" : ",",
 				channel_id2name(info->position[i]));
 	pw_properties_set(props, SPA_KEY_AUDIO_POSITION, s);
 }
@@ -180,6 +156,8 @@ struct module *create_module_remap_sink(struct impl *impl, const char *argument)
 	struct spa_audio_info_raw playback_info = { 0 };
 	int res;
 
+	PW_LOG_TOPIC_INIT(mod_topic);
+
 	props = pw_properties_new_dict(&SPA_DICT_INIT_ARRAY(module_remap_sink_info));
 	capture_props = pw_properties_new(NULL, NULL);
 	playback_props = pw_properties_new(NULL, NULL);
@@ -191,10 +169,8 @@ struct module *create_module_remap_sink(struct impl *impl, const char *argument)
 		module_args_add_props(props, argument);
 
 	if ((str = pw_properties_get(props, "sink_name")) != NULL) {
-		pw_properties_set(props, PW_KEY_NODE_NAME, str);
+		pw_properties_set(capture_props, PW_KEY_NODE_NAME, str);
 		pw_properties_set(props, "sink_name", NULL);
-	} else {
-		pw_properties_set(props, PW_KEY_NODE_NAME, "null");
 	}
 	if ((str = pw_properties_get(props, "sink_properties")) != NULL) {
 		module_args_add_props(capture_props, str);
@@ -231,12 +207,12 @@ struct module *create_module_remap_sink(struct impl *impl, const char *argument)
 	if ((str = pw_properties_get(props, "remix")) != NULL) {
 		/* Note that the boolean is inverted */
 		pw_properties_set(playback_props, PW_KEY_STREAM_DONT_REMIX,
-				pw_properties_parse_bool(str) ? "false" : "true");
+				module_args_parse_bool(str) ? "false" : "true");
 		pw_properties_set(props, "remix", NULL);
 	}
 
-	if (pw_properties_get(capture_props, PW_KEY_NODE_PASSIVE) == NULL)
-		pw_properties_set(capture_props, PW_KEY_NODE_PASSIVE, "true");
+	if (pw_properties_get(playback_props, PW_KEY_NODE_PASSIVE) == NULL)
+		pw_properties_set(playback_props, PW_KEY_NODE_PASSIVE, "true");
 
 	module = module_new(impl, &module_remap_sink_methods, sizeof(*d));
 	if (module == NULL) {
@@ -252,12 +228,9 @@ struct module *create_module_remap_sink(struct impl *impl, const char *argument)
 
 	return module;
 out:
-	if (props)
-		pw_properties_free(props);
-	if (playback_props)
-		pw_properties_free(playback_props);
-	if (capture_props)
-		pw_properties_free(capture_props);
+	pw_properties_free(props);
+	pw_properties_free(playback_props);
+	pw_properties_free(capture_props);
 	errno = -res;
 	return NULL;
 }
